pub struct InitiatorParameters { /* private fields */ }Expand description
Parameters for the initiator side of a PQXDH key agreement.
The initiator fetches the recipient’s pre-key bundle from the server and uses it together with their own identity and ephemeral keys to compute a shared secret.
Implementations
Sourceimpl InitiatorParameters
impl InitiatorParameters
pub fn new( our_identity_key_pair: IdentityKeyPair, our_ephemeral_key_pair: KeyPair, their_identity_key: IdentityKey, their_signed_pre_key: PublicKey, their_ratchet_key: PublicKey, their_kyber_pre_key: PublicKey, self_session: bool, ) -> Self
pub fn set_their_one_time_pre_key(&mut self, ec_public: PublicKey)
pub fn our_identity_key_pair(&self) -> &IdentityKeyPair
pub fn our_ephemeral_key_pair(&self) -> &KeyPair
pub fn their_identity_key(&self) -> &IdentityKey
pub fn their_signed_pre_key(&self) -> &PublicKey
pub fn their_one_time_pre_key(&self) -> Option<&PublicKey>
pub fn their_kyber_pre_key(&self) -> &PublicKey
pub fn their_ratchet_key(&self) -> &PublicKey
pub fn self_session(&self) -> bool